import {
  select,
  json,
  tree,
  hierarchy,
  linkHorizontal,
  zoom,
  event
} from 'd3';
const svg = select('svg');
const width = document.body.clientWidth;
const height = document.body.clientHeight;
const margin = { top: 0, right: 60, bottom: 0, left: 105};
// adjusting the height and width for the tree
const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;
const treeLayout = tree().size([innerHeight, innerWidth]);
const zoomG = svg
    .attr('width', width)
    .attr('height', height)
  .append('g');
// positioning the layout of the tree
const g = zoomG.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
// method to show in zoom mode 
svg.call(zoom().on('zoom', () => {
  zoomG.attr('transform', event.transform);
}));
// parsing the data 
json('data.json')
  .then(data => {
    const root = hierarchy(data);
    const links = treeLayout(root).links();
    const linkPathGenerator = linkHorizontal()
      .x(d => d.y)
      .y(d => d.x);
 // setting the link to nodes 
    g.selectAll('path').data(links)
      .enter().append('path')
        .attr('d', linkPathGenerator);
 // adding of node and labeling them 
    g.selectAll('text').data(root.descendants())
      .enter().append('text')
        .attr('x', d => d.y)
        .attr('y', d => d.x)
        .attr('dy', '0.20em')
        .attr('text-anchor', d => d.children ? 'middle' : 'start') // make the node label in center 
        .attr('font-size', d => 3.6 - d.depth + 'em') // assigning the value for depth 
        .text(d => d.data.data.id)
  			.attr('fill', d => d.data.data.color);
  });